Class: RailsAppGenerator::AppBuilder

Inherits:
Rails::AppBuilder
  • Object
show all
Defined in:
lib/rails_app_generator/app_builder.rb

Overview

The application builder allows you to override elements of the application generator without being forced to reverse the operations of the default generator.

Instance Method Summary collapse

Instance Method Details

#gemfile ⇒ Object

def ruby_version RailsAppGenerator::AddOns::RubyVersion.new(Context.new(options)).apply end



26
27
28
# File 'lib/rails_app_generator/app_builder.rb', line 26

def gemfile
  template 'Gemfile.erb', 'Gemfile'
end

#readme ⇒ Object

def credentials super

This sets up credentials using a custom template for both development and production use

RailsAppGenerator::AddOns::Credentials.apply end



18
19
20
# File 'lib/rails_app_generator/app_builder.rb', line 18

def readme
  template 'README.md.erb', 'README.md'
end